#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2002-2005 Free Software Foundation
#
# FILE:
# __init__.py
#
# DESCRIPTION:
#
# NOTES:
#


from constants import *

__classes__ = [
  "sio",
  "Application",
  "Button",
  "CheckBox",
  "CheckBoxGroup",
  "ComboBox",
  "Container",
  "Control",
  "Dialog",
  "DirChooser",
  "FileSelectPad",
  "FileSelector",
  "FocusedLabel",
  "Frame",
  "GraphicObject",
  "GroupBox",
  "InputBox",
  "Label",
  "Menu",
  "MenuBar",
  "MenuItem",
  "MsgBoxOK",
  "MsgBoxYesNo",
  "Progress",
  "RadioButton",
  "RadioGroup",
  "ScrollBar",
  "StatusBar",
  "TextBox",
  "TextArea",
  "VButton",
  "VScrollBar "
]

for module in  __classes__ :
  exec "from %s import %s" % (module, module)

